@@ -2,11 +2,12 @@ package BeerDB;
 use Maypole::Application;
 use Class::DBI::Loader::Relationship;
 
-sub debug { $ENV{BEERDB_DEBUG} }
+sub debug { $ENV{BEERDB_DEBUG} || 0 }
 # This is the sample application.  Change this to the path to your
 # database. (or use mysql or something)
 use constant DBI_DRIVER => 'SQLite';
-use constant DATASOURCE => 't/beerdb.db';
+use constant DATASOURCE => $ENV{BEERDB_DATASOURCE} || 't/beerdb.db';
+
 
 BEGIN {
     my $dbi_driver = DBI_DRIVER;
@@ -25,10 +26,15 @@ BEGIN {
 # Give it a name.
 BeerDB->config->application_name('The Beer Database');
 
-# Change this to the root of the web space.
-BeerDB->config->uri_base("http://localhost/beerdb/");
-#BeerDB->config->uri_base("http://neo.trinity-house.org.uk/beerdb/");
+# Change this to the root of the web site for your maypole application.
+BeerDB->config->uri_base( $ENV{BEERDB_BASE} || "http://localhost/beerdb/" );
 
+# Change this to the htdoc root for your maypole application.
+
+my @root=  ('t/templates'); 
+push @root,$ENV{BEERDB_TEMPLATE_ROOT} if ($ENV{BEERDB_TEMPLATE_ROOT});
+BeerDB->config->template_root( [@root] ); 
+# Specify the rows per page in search results, lists, etc : 10 is a nice round number
 BeerDB->config->rows_per_page(10);
 
 # Handpumps should not show up.
@@ -38,8 +44,16 @@ BeerDB::Style->untaint_columns( printable => [qw/name notes/] );
 BeerDB::Beer->untaint_columns(
     printable => [qw/abv name price notes url/],
     integer => [qw/style brewery score/],
-    date =>[ qw/date/],
+    date =>[ qw/tasted/],
 );
+BeerDB::Pub->untaint_columns(printable => [qw/name notes url/]);
+
+# Required Fields
+BeerDB->config->{brewery}{required_cols} = [qw/name/];
+BeerDB->config->{style}{required_cols} = [qw/name/];
+BeerDB->config->{beer}{required_cols} = [qw/brewery name price/];
+BeerDB->config->{pub}{required_cols} = [qw/name/];
+
 BeerDB->config->{loader}->relationship($_) for (
     "a brewery produces beers",
     "a style defines beers",
